#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 quickcheck-instances
version:              0.3.33
visibility:           public
id:                   quickcheck-instances-0.3.33-1oX6pslAOKwLssdigXTEcO
key:                  quickcheck-instances-0.3.33-1oX6pslAOKwLssdigXTEcO
license:              BSD-3-Clause
copyright:            Copyright 2012-2016 Antoine Latter, 2017-2019 Oleg Grenrus
maintainer:           Oleg Grenrus <oleg.grenrus@iki.fi>
author:
    Antoine Latter <aslatter@gmail.com>, Oleg Grenrus <oleg.grenrus@iki.fi>

homepage:             https://github.com/haskellari/qc-instances
synopsis:             Common quickcheck instances
description:
    QuickCheck instances.

    The goal is to supply QuickCheck instances for
    types provided by the Haskell Platform.

    Since all of these instances are provided as
    orphans, I recommend that you do not use this library
    within another library module, so that you don'\''t
    impose these instances on down-stream consumers of
    your code.

category:             Testing
abi:                  fb7fc376f0ea15d39f5fa2c0b5fcca0a
exposed:              True
exposed-modules:
    Test.QuickCheck.Instances Test.QuickCheck.Instances.Array
    Test.QuickCheck.Instances.Array.Byte
    Test.QuickCheck.Instances.ByteString
    Test.QuickCheck.Instances.CaseInsensitive
    Test.QuickCheck.Instances.Containers
    Test.QuickCheck.Instances.DataFix
    Test.QuickCheck.Instances.Hashable
    Test.QuickCheck.Instances.Natural Test.QuickCheck.Instances.OldTime
    Test.QuickCheck.Instances.Primitive
    Test.QuickCheck.Instances.Scientific
    Test.QuickCheck.Instances.Semigroup Test.QuickCheck.Instances.Solo
    Test.QuickCheck.Instances.Strict Test.QuickCheck.Instances.Tagged
    Test.QuickCheck.Instances.Text Test.QuickCheck.Instances.Text.Short
    Test.QuickCheck.Instances.These Test.QuickCheck.Instances.Time
    Test.QuickCheck.Instances.Transformer
    Test.QuickCheck.Instances.UUID
    Test.QuickCheck.Instances.UnorderedContainers
    Test.QuickCheck.Instances.Vector Test.QuickCheck.Instances.Void

hidden-modules:       Test.QuickCheck.Instances.CustomPrelude
import-dirs:          /usr/lib/ghc-9.6.6/site-local/quickcheck-instances-0.3.33
library-dirs:         /usr/lib/ghc-9.6.6/site-local/quickcheck-instances-0.3.33
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/quickcheck-instances-0.3.33
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-quickcheck-instances
hs-libraries:         HSquickcheck-instances-0.3.33-1oX6pslAOKwLssdigXTEcO
depends:
    OneTuple-0.4.3-7c90wWx2gtaHd4qmhQodcT
    QuickCheck-2.15.0.1-5Y9HZXtqNX41xwYMFzmoSZ array-0.5.6.0
    base-4.18.2.1 bytestring-0.11.5.3
    case-insensitive-1.2.1.0-9SCmNmyRT1LDc1Bi3mXj6e containers-0.6.7
    data-fix-0.3.4-2rh4GrqviLwB9ICs2I8b2X
    hashable-1.4.7.0-A1kp0rRlB2mBNtk1x2NHGT
    integer-logarithms-1.0.4-KbFC6qwZjYZ7hO9Nzc0OXW
    old-time-1.1.1.0-9WWjmNUa02UkaP5dbkbXm
    primitive-0.9.1.0-IuEzc1i7B8w72ArTAK2GO5
    scientific-0.3.8.1-6O6hUkglHhJ388M1FqOkp1
    splitmix-0.1.3.1-9NMcSdfFQwOmZZO8kCEkG
    strict-0.5.1-KMUGMGZjfNHEUkCdyw3BGN
    tagged-0.8.10-9VJfLOM9ch68xR35ePL46j text-2.0.2
    text-short-0.1.6.1-9yq7wAqTYnE4rbzlLklazA
    these-1.2.1-3rx1V5GanI22DfvaVffCVj
    time-compat-1.9.9-LsDKrCmon3qFMTTQUp8969 transformers-0.6.1.0
    unordered-containers-0.2.21-1uyZH24PObnIj7baK8tBEp
    uuid-types-1.0.6.1-53twgZjoCdX6W5agCY9RG4
    vector-0.13.2.0-5a59Ladt6HH20irTaXAFu7

haddock-interfaces:
    /usr/share/doc/haskell-quickcheck-instances/html/quickcheck-instances.haddock

haddock-html:         /usr/share/doc/haskell-quickcheck-instances/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

